/* tslint:disable */
/* eslint-disable */
export const memory: WebAssembly.Memory;
export const __wbg_session_free: (a: number, b: number) => void;
export const __wbg_sessionbuilder_free: (a: number, b: number) => void;
export const __wbg_sessionterminationinfo_free: (a: number, b: number) => void;
export const __wbg_deviceevent_free: (a: number, b: number) => void;
export const __wbg_inputtransaction_free: (a: number, b: number) => void;
export const __wbg_clipboarddata_free: (a: number, b: number) => void;
export const __wbg_clipboarditem_free: (a: number, b: number) => void;
export const __wbg_ironerror_free: (a: number, b: number) => void;
export const setup: (a: number, b: number) => void;
export const session_run: (a: number) => any;
export const session_desktopSize: (a: number) => number;
export const session_applyInputs: (a: number, b: number) => [number, number];
export const session_releaseAllInputs: (a: number) => [number, number];
export const session_synchronizeLockKeys: (a: number, b: number, c: number, d: number, e: number) => [number, number];
export const session_shutdown: (a: number) => [number, number];
export const session_onClipboardPaste: (a: number, b: number) => any;
export const session_resize: (a: number, b: number, c: number, d: number, e: number, f: number) => void;
export const session_supportsUnicodeKeyboardShortcuts: (a: number) => number;
export const session_invokeExtension: (a: number, b: number) => [number, number, number];
export const sessionbuilder_create: () => number;
export const sessionbuilder_username: (a: number, b: number, c: number) => number;
export const sessionbuilder_destination: (a: number, b: number, c: number) => number;
export const sessionbuilder_serverDomain: (a: number, b: number, c: number) => number;
export const sessionbuilder_password: (a: number, b: number, c: number) => number;
export const sessionbuilder_proxyAddress: (a: number, b: number, c: number) => number;
export const sessionbuilder_authToken: (a: number, b: number, c: number) => number;
export const sessionbuilder_desktopSize: (a: number, b: number) => number;
export const sessionbuilder_renderCanvas: (a: number, b: any) => number;
export const sessionbuilder_setCursorStyleCallback: (a: number, b: any) => number;
export const sessionbuilder_setCursorStyleCallbackContext: (a: number, b: any) => number;
export const sessionbuilder_remoteClipboardChangedCallback: (a: number, b: any) => number;
export const sessionbuilder_forceClipboardUpdateCallback: (a: number, b: any) => number;
export const sessionbuilder_canvasResizedCallback: (a: number, b: any) => number;
export const sessionbuilder_extension: (a: number, b: number) => number;
export const sessionbuilder_connect: (a: number) => any;
export const sessionterminationinfo_reason: (a: number) => [number, number];
export const deviceevent_mouseButtonPressed: (a: number) => number;
export const deviceevent_mouseButtonReleased: (a: number) => number;
export const deviceevent_mouseMove: (a: number, b: number) => number;
export const deviceevent_wheelRotations: (a: number, b: number, c: number) => number;
export const deviceevent_keyPressed: (a: number) => number;
export const deviceevent_keyReleased: (a: number) => number;
export const deviceevent_unicodePressed: (a: number) => number;
export const deviceevent_unicodeReleased: (a: number) => number;
export const inputtransaction_create: () => number;
export const inputtransaction_addEvent: (a: number, b: number) => void;
export const clipboarddata_create: () => number;
export const clipboarddata_addText: (a: number, b: number, c: number, d: number, e: number) => void;
export const clipboarddata_addBinary: (a: number, b: number, c: number, d: number, e: number) => void;
export const clipboarddata_items: (a: number) => [number, number];
export const clipboarddata_isEmpty: (a: number) => number;
export const clipboarditem_mimeType: (a: number) => [number, number];
export const clipboarditem_value: (a: number) => any;
export const ironerror_backtrace: (a: number) => [number, number];
export const ironerror_kind: (a: number) => number;
export const __wbg_rdpfile_free: (a: number, b: number) => void;
export const rdpfile_create: () => number;
export const rdpfile_parse: (a: number, b: number, c: number) => void;
export const rdpfile_write: (a: number) => [number, number];
export const rdpfile_insertStr: (a: number, b: number, c: number, d: number, e: number) => void;
export const rdpfile_insertInt: (a: number, b: number, c: number, d: number) => void;
export const rdpfile_getStr: (a: number, b: number, c: number) => [number, number];
export const rdpfile_getInt: (a: number, b: number, c: number) => number;
export const main: () => void;
export const __wbg_desktopsize_free: (a: number, b: number) => void;
export const __wbg_get_desktopsize_width: (a: number) => number;
export const __wbg_set_desktopsize_width: (a: number, b: number) => void;
export const __wbg_get_desktopsize_height: (a: number) => number;
export const __wbg_set_desktopsize_height: (a: number, b: number) => void;
export const desktopsize_create: (a: number, b: number) => number;
export const __wbg_extension_free: (a: number, b: number) => void;
export const extension_create: (a: number, b: number, c: any) => number;
export const wasm_bindgen__convert__closures_____invoke__h1a0b091d40d0d4be: (a: number, b: number) => void;
export const wasm_bindgen__closure__destroy__h0022e787a053a40f: (a: number, b: number) => void;
export const wasm_bindgen__convert__closures_____invoke__h8a105ca3ff48d408: (a: number, b: number, c: any) => void;
export const wasm_bindgen__closure__destroy__hf477c56b59a93d44: (a: number, b: number) => void;
export const wasm_bindgen__convert__closures_____invoke__h1b6eeedec099a8de: (a: number, b: number, c: any) => void;
export const wasm_bindgen__closure__destroy__h52a2faaf1da3e630: (a: number, b: number) => void;
export const wasm_bindgen__convert__closures_____invoke__h4d617c7b6d398e2c: (a: number, b: number) => void;
export const wasm_bindgen__convert__closures_____invoke__h941949ddb830799f: (a: number, b: number, c: any, d: any) => void;
export const __wbindgen_malloc: (a: number, b: number) => number;
export const __wbindgen_realloc: (a: number, b: number, c: number, d: number) => number;
export const __wbindgen_exn_store: (a: number) => void;
export const __externref_table_alloc: () => number;
export const __wbindgen_externrefs: WebAssembly.Table;
export const __wbindgen_free: (a: number, b: number, c: number) => void;
export const __externref_table_dealloc: (a: number) => void;
export const __externref_drop_slice: (a: number, b: number) => void;
export const __wbindgen_start: () => void;
